# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms
from django.contrib.auth.models import User, Group

from .models import UserProfile, UserProfileParentRelation, UserClass, UserLeaveRecord, USER_LEAVE_TYPE_CHOICES
from django.forms.models import inlineformset_factory
from .validators import user_sn_validator


class UserForm(forms.ModelForm):
    class Meta:
        model = User
        fields = ["first_name"]

    def __init__(self, userprofile, *args, **kwargs):
        super(UserForm, self).__init__(*args, **kwargs)

        agent_queryset = UserProfile.objects.filter(user__groups__name__in=UserProfile.get_agent_groupname_list())

        lecturer_queryset = UserProfile.objects.filter(
            user__groups__name__in=UserProfile.get_lecturer_groupname_list())
        # ==可添加/修改客服，讲师/没有讲师的助教/既没讲师又没班级的学生==
        if userprofile.is_role('lecturer') or (userprofile.is_role('mentor') and not userprofile.lecturer) or (
                userprofile.is_role('student') and not userprofile.lecturer and not userprofile.user_class):
            self.fields['agent'] = forms.ModelChoiceField(label='客服', queryset=agent_queryset, required=False)
            self.initial['agent'] = kwargs["instance"].userprofile.agent

        # ==可添加/修改讲师，助教/没有班级的学生==
        if userprofile.is_role('mentor') or (userprofile.is_role('student') and not userprofile.user_class):
            self.fields['lecturer'] = forms.ModelChoiceField(label='讲师', queryset=lecturer_queryset, required=False)
            self.initial['lecturer'] = kwargs["instance"].userprofile.lecturer


class UserProfileForm(forms.ModelForm):
    class Meta:
        model = UserProfile
        fields = ['start_date', "user_class"]


profile_inline_formset = inlineformset_factory(User, UserProfile, form=UserProfileForm, can_delete=False)


class UserAvatarForm(forms.ModelForm):
    avatar = forms.FileField(label='')

    class Meta:
        model = UserProfile
        fields = ['avatar']


class UserSearchForm(forms.Form):
    status_list = ((0, '全部'), (1, '正常'), (999, '请假'), (2, '暂停'), (3, '禁用'))
    status = forms.ChoiceField(choices=status_list, label='状态', required=False)
    group = forms.ModelChoiceField(queryset=Group.objects.all(), label='用户组', required=False)
    student_id = forms.CharField(label='学号', required=False)
    first_name = forms.CharField(label='用户姓名', required=False)
    start_expire_date = forms.CharField(label='结课日期', required=False)
    end_expire_date = forms.CharField(label='至', required=False)

    # class Meta:
    #     model = User
    #     fields = ["student_id","first_name"]


class UserProfileParentsForm(forms.Form):
    parent_queryset = User.objects.filter(groups__name__in=UserProfile.get_parent_groupname_list())
    parent = forms.ModelChoiceField(queryset=parent_queryset, label='家长助教', required=False)
    # class Meta:
    #     model = UserProfileParentRelation
    #     fields = ['parent']


class UserClassForm(forms.ModelForm):
    assistant_queryset = User.objects.filter(groups__name__in=UserProfile.get_assistant_groupname_list())
    assistant = forms.ModelChoiceField(queryset=assistant_queryset, label='助教', required=False)

    class Meta:
        model = UserClass
        fields = ["name", 'assistant', "status"]


class UserClassDashBoardSearchForm(forms.ModelForm):
    time = forms.ChoiceField(
        choices=((u"本日", '本日'), (u"昨日", '昨日'), (u"本周", '本周'), (u"上周", '上周'), (u"本月", '本月'), (u"上月", '上月')), label='时间',
        required=True)
    name = forms.CharField(label='班级名称', required=False)

    class Meta:
        model = UserClass
        fields = ['time', "status", "name"]


class UserClassSearchForm(forms.Form):
    status = forms.ChoiceField(choices=((0, '全部'), (1, '正常'), (2, "已结业"),), required=False, label='状态')
    class_name = forms.CharField(label='班级名称', required=False)
    assistant_name = forms.CharField(label='助教姓名', required=False)


class UserGroupForm(forms.ModelForm):
    class Meta:
        model = User
        fields = ['groups']


class UserSNForm(forms.ModelForm):
    sn = forms.CharField(label='缦客号', validators=[user_sn_validator])

    class Meta:
        model = UserProfile
        fields = ['sn']


# 请假/延期
class UserLeaveRecordForm(forms.ModelForm):
    type_choices = ((1, "请假"), (3, "延期"))
    type = forms.ChoiceField(choices=type_choices, label='类型')

    class Meta:
        model = UserLeaveRecord
        fields = ['type', "start", "end", "info"]


# 请假/延期
class UserLeaveRecordCancelForm(forms.ModelForm):
    type_choices = ((2, "销假"),)
    type = forms.ChoiceField(choices=type_choices, label='类型')

    class Meta:
        model = UserLeaveRecord
        fields = ['type', "start", "info"]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-29 06:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0030_userclass_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='userclass',
            name='passed_at',
            field=models.DateTimeField(null=True, verbose_name='\u7ed3\u4e1a\u65f6\u95f4'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from datetime import datetime
from django import template

from django.contrib.auth.models import User, Group, Permission
from bee_django_user.exports import get_user_leave_status

register = template.Library()


# 求两个值的差的绝对值
@register.filter
def get_difference_abs(a, b):
    return abs(a - b)


# 组是否有权限
@register.filter
def has_permission(group, permission_name):
    try:
        if group.permissions.get(codename=permission_name):
            return True
        return False
    except:
        return False


# 组是否有权限
@register.filter
def has_manage(user):
    try:
        if user.userprofile.has_group("管理员") or user.userprofile.has_group("客服") or user.userprofile.has_group("助教"):
            return True

    except:
        return False
    return False


# 本地化时间
# @register.filter
# def local_datetime(_datetime):
#     return filter_local_datetime(_datetime)

# 获取学生的请假状态
@register.simple_tag
def get_leave_status(user):
    status = get_user_leave_status(user)
    if status:
        return "请假中"
    return


# 获取【本周】学生练习的分钟数，次数，助教观看次数
@register.simple_tag
def get_user_live_detail(user, time):
    try:
        from bee_django_course.models import UserLive
        if time == u'本日':
            scope = 'day'
            offset = 0
        elif time == u'昨日':
            scope = 'day'
            offset = -1
        elif time == u'本周':
            scope = 'week'
            offset = 0
        elif time == u'上周':
            scope = 'week'
            offset = -1
        elif time == u'本月':
            scope = 'month'
            offset = 0
        elif time == u'上月':
            scope = 'month'
            offset = -1
        else:
            return 0, 0, 0
        return UserLive.get_user_live_detail([user], scope=scope, offset=offset)
    except Exception as e:
        return 0, 0, 0


# 获取班级剩余m币
@register.filter
def get_class_coin(class_id):
    try:
        from bee_django_coin.models import OtherCoinCount
        record = OtherCoinCount.objects.get(coin_type__identity='user_class', coin_content_id=class_id)
        return record.count
    except:
        return None



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-23 09:15
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0034_auto_20190923_1715'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userleaverecord',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-09 06:54
from __future__ import unicode_literals

from django.db import migrations
import imagekit.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0027_auto_20190807_1410'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userprofile',
            name='avatar',
            field=imagekit.models.fields.ProcessedImageField(blank=True, null=True, upload_to='avatars', verbose_name='\u5934\u50cf'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-19 07:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0029_auto_20190812_1820'),
    ]

    operations = [
        migrations.AddField(
            model_name='userclass',
            name='status',
            field=models.IntegerField(choices=[(1, '\u6b63\u5e38'), (2, '\u5df2\u7ed3\u4e1a')], default=1, verbose_name='\u73ed\u7ea7\u72b6\u6001'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-07 06:10
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0026_auto_20190630_1758'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='agent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='agent_user', to='bee_django_user.UserProfile'),
        ),
        migrations.AddField(
            model_name='userprofile',
            name='gensee_room_id',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u76f4\u64ad\u95f4ID'),
        ),
        migrations.AddField(
            model_name='userprofile',
            name='wxservice_openid',
            field=models.CharField(blank=True, max_length=180, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-12 05:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0036_userprofile_live_mins'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userclass',
            name='lecturer',
        ),
        migrations.AddField(
            model_name='userprofile',
            name='lecturer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='lecturer_user', to='bee_django_user.UserProfile', verbose_name='\u8bb2\u5e08'),
        ),
    ]
